v1/compiler
library
Classes
-
DependencyElement
-
Statically analyzed information necessary to satisfy a dependency.
-
DependencyInvocation<E extends Element?>
-
Statically analyzed arguments needed to invoke a constructor or function.
-
DependencyReader
-
Support for reading and parsing a class or function's "dependencies".
-
DirectiveVisitor
-
Utility class for visiting important methods and fields in an
@Directive.
-
InjectorEmitter
-
Generates
.dart source code given a list of providers to bind.
-
InjectorReader
-
Determines details for generating code as a result of
@Injector.generate.
-
ModuleElement
-
-
ModuleReader
-
Support for reading and parsing constant
Modules into data structures.
-
NgAssetReader
-
Wraps an
AssetReader to provide an ergonomic API for finding input files.
-
OpaqueTokenElement
-
A statically parsed
OpaqueToken used as an identifier for injection.
-
ProviderElement
-
A statically parsed
Provider.
-
ProviderReader
-
Support for reading and parsing constant
Providers into data structures.
-
SplitDartEmitter
-
-
TemplateOutliner
-
Generates an outline of the public API of a
.template.dart file.
-
TokenElement
-
A statically parsed token used as an identifier for injection.
-
TokenReader
-
Support for reading and parsing a "token" for dependency injection.
-
TypedElement
-
A statically parsed
Typed used to specify type arguments on a directive.
-
TypedReader
-
Parses types from compile-time constant
Typed expressions.
-
TypeLink
-
An abstraction over pointing to a type in a given Dart source file.
-
TypeTokenElement
-
A statically parsed
Type used as an identifier for injection.
-
UseClassProviderElement
-
A statically parsed
Provider that describes a new class instance.
-
UseFactoryProviderElement
-
A statically parsed
Provider that describes a function invocation.
-
UseValueProviderElement
-
A statically parsed
Provider that describes a constant expression.
Functions
-
getTypeName(DartType? type)
→ String?
-
Forwards and backwards-compatible method of getting the "name" of
type.
-
isGlobalSingletonService(TypeLink service)
→ bool
-
-
linkToReference(TypeLink link, LibraryReader library)
→ TypeReference
-
Returns as a
code_builder TypeReference for code generation.
-
linkTypeOf(DartType type)
→ TypeLink
-
Returns a TypeLink to the given statically analyzed
DartType.
-
typeArgumentOf(DartObject object, [int index = 0])
→ DartType
-
Returns the bound
DartType from the instance object.
-
unerasedTypeOf(DartObject object)
→ DartType?
-
Returns the type of the constant
object, without extension type erasure.
-
unerasedTypeValueOf(DartObject object)
→ DartType?
-
Returns the
Type value of the constant object, without extension type
erasure.
-
urlOf(Element? element, [String? name])
→ Uri
-
Returns a canonical URL pointing to
element.