AnalyzedClass class

A wrapper around ClassElement which exposes the functionality needed for the view compiler to find types for expressions.

Constructors

AnalyzedClass(ClassElement classElement, {bool isMockLike = false, Map<String, DartType?> locals = const {}})
AnalyzedClass.from(AnalyzedClass other, {Map<String, DartType?> additionalLocals = const {}})

Properties

classElement → ClassElement
final
hashCode → int
The hash code for this object.
no setterinherited
isMockLike → bool
Whether this class has mock-like behavior.
final
locals → Map<String, DartType?>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited