Conditional class

A ternary or where condition will either pick trueExpr or falseExpr.

// a ? b : c
Conditional(
  VariableRead('a'),
  VariableRead('b'),
  VariableRead('c'),
)
Inheritance

Constructors

Conditional(AST condition, AST trueExp, AST falseExp)

Properties

condition → AST
final
falseExp → AST
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trueExp → AST
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit<R, C, CO extends C>(AstVisitor<R, C?> visitor, [CO? context]) → R
Given a visitor and optionally a context, produce a return value R.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited