IfNull class

Represents the "if null" (??) operator.

IfNull(VariableRead('a'), VariableRead('b')) // a ?? b
Inheritance

Constructors

IfNull(AST condition, AST nullExp)

Properties

condition → AST
Condition for the null check and result if it is not null.
final
hashCode → int
The hash code for this object.
no setterinherited
nullExp → AST
Result if the condition operand is null.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit<R, C, CO extends C>(AstVisitor<R, C?> visitor, [CO? context]) → R
Given a visitor and optionally a context, produce a return value R.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited