PropertyRead class

Reads a property (getter or field) name from receiver.

PropertyRead(VariableRead('a'), 'b') // a.b
Inheritance

Constructors

PropertyRead(AST receiver, String name)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the field or getter.
final
receiver → AST
Context to read name from.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit<R, C, CO extends C>(AstVisitor<R, C?> visitor, [CO? context]) → R
Given a visitor and optionally a context, produce a return value R.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited