PropertyWrite class

Writes a property (setter or field) name to receiver.

PropertyWrite(VariableRead('a'), 'b', LiteralPrimitive('c')) // a.b = 'c'
Inheritance

Constructors

PropertyWrite(AST receiver, String name, AST value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Name of the field or setter.
final
receiver → AST
Context to write name to.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → AST
Value to write.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit<R, C, CO extends C>(AstVisitor<R, C?> visitor, [CO? context]) → R
Given a visitor and optionally a context, produce a return value R.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited