BoundDirectivePropertyAst class

A directive property binding.

Implemented types

Constructors

BoundDirectivePropertyAst(String memberName, String templateName, BoundValue value, SourceSpan sourceSpan)

Properties

hashCode → int
The hash code for this object.
no setterinherited
memberName → String
The name of the property member (field or setter) declared on the directive class.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceSpan → SourceSpan
The source span from which this node was parsed.
final
templateName → String
The name of the input, optionally declared by an input annotation.
final
value → BoundValue
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit<R, C, CO extends C>(TemplateAstVisitor<R, C> visitor, CO context) → R
Visit this node and possibly transform it.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited