ProviderAst class

A provider declared on an element.

Implemented types

Constructors

ProviderAst(CompileTokenMetadata token, bool multiProvider, List<CompileProviderMetadata> providers, ProviderAstType providerType, SourceSpan sourceSpan, {required bool eager, bool isReferencedOutsideBuild = true, CompileTypeMetadata? typeArgument, bool visibleForInjection = false})

Properties

eager → bool
Whether provider should be eagerly created at build time.
final
hashCode → int
The hash code for this object.
no setterinherited
isReferencedOutsideBuild → bool
Whether this provider is referenced outside of AppView.build().
final
multiProvider → bool
Whether the provider's token is a MultiToken.
final
providers → List<CompileProviderMetadata>
final
providerType → ProviderAstType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceSpan → SourceSpan
The source span from which this node was parsed.
final
token → CompileTokenMetadata
final
typeArgument → CompileTypeMetadata?
The type provided by this provider.
final
visibleForInjection → bool
Whether the provider is visible for injection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit<R, C, CO extends C>(TemplateAstVisitor<R, C> visitor, CO context) → R
Visit this node and possibly transform it.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited