TemplateContext class

Constructors

TemplateContext({required ExpressionParser parser, required ElementSchemaRegistry schemaRegistry, required CompileDirectiveMetadata component, required List<CompileDirectiveMetadata> directives})

Properties

component → CompileDirectiveMetadata
final
directives → List<CompileDirectiveMetadata>
final
exports → List<CompileIdentifierMetadata>
no setter
hashCode → int
The hash code for this object.
no setterinherited
parser → ExpressionParser
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaRegistry → ElementSchemaRegistry
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited