CompileMethod class

Creates a list of statements for a method body that include debug context.

Use addStmt/addStmts to add statements at the current checkpoint.

Constructors

CompileMethod()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
isNotEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addStmt(Statement stmt) → void
addStmts(List<Statement> stmts) → void
addStmtsIfFirstCheck(List<Statement> stmts) → void
If the last added statement is an if (firstCheck), re-use that if-block.
findReadVarNames() → Set<String?>
Returns set of variable reads in method.
finish() → List<Statement>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited