Placeholder class

Generates an empty file to indicate .template.dart will exist.

For files in the same build action (i.e. dart_library for Bazel and a module for build_runner), we can't rely on a .template.dart existing on disk as an indication whether one will exist, or not.

Instead, a .ng_placeholder file may be emitted in an earlier build phase in order to indicate "a .template.dart of the same will exist by the time it is necessary to compile".

Constructors

Placeholder()
const

Properties

buildExtensions Map<String, List<String>>
Mapping from input file extension to output file extensions.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildStep buildStep) Future<void>
Generates the outputs for a given BuildStep.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited